==> django-inplaceedit-bootstrap-0.1.1.tar.gz: django-inplaceedit-bootstrap-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2013 by Pablo Martín <goinnn@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this programe.  If not, see <http://www.gnu.org/licenses/>.

import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(
    name="django-inplaceedit-bootstrap",
    version="0.1.1",
    author="Pablo Martin",
    author_email="goinnn@gmail.com",
    description="Integration of django-inplaceedit and bootstrap",
    long_description=(read('README.rst') + '\n\n' + read('CHANGES.rst')),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
    license="LGPL 3",
    keywords="django,inplace,inline edit, bootstrap,inline form,inline,inplace edit,inplace form,ajax",
    url='https://github.com/goinnn/django-inplaceedit-bootstrap',
    packages=find_packages('.'),
    include_package_data=True,
    zip_safe=False,
    install_requires=['django-inplaceedit>=1.2.3']
)

==> django-inplaceedit-bootstrap-0.2.0.tar.gz: django-inplaceedit-bootstrap-0.2.0/setup.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2013 by Pablo Martín <goinnn@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this programe.  If not, see <http://www.gnu.org/licenses/>.

import os
from setuptools import setup, find_packages


def read(*rnames):
    return open(os.path.join(os.path.dirname(__file__), *rnames)).read()

setup(
    name="django-inplaceedit-bootstrap",
    version="0.2.0",
    author="Pablo Martin",
    author_email="goinnn@gmail.com",
    description="Integration of django-inplaceedit and bootstrap",
    long_description=(read('README.rst') + '\n\n' + read('CHANGES.rst')),
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Django',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
    ],
    license="LGPL 3",
    keywords="django,inplace,inline edit, bootstrap,inline form,inline,inplace edit,inplace form,ajax",
    url='https://github.com/django-inplaceedit/django-inplaceedit-bootstrap',
    packages=find_packages('.'),
    include_package_data=True,
    zip_safe=False,
    install_requires=['django-inplaceedit>=1.4.0']
)
